applies to the python source of the CPyMAD package::

    Copyright (c) 2013-2015, HIT - Heidelberg Ion-Therapy Center

    To the extent possible under law, the person who associated CC0 with
    CPyMAD has waived all copyright and related or neighboring rights to
    CPyMAD.

    You should have received a copy of the CC0 legalcode along with this
    work. If not, see <http://creativecommons.org/publicdomain/zero/1.0/>.

Note that this package is a heavily modified fork of the original
cern-cpymad package developed at CERN::

    Copyright (c) 2011, CERN. All rights reserved.

    Licensed under the Apache License, Version 2.0 (the "License");
    you may not use cern-cpymad except in compliance with the License.
    You may obtain a copy of the License at

        http://www.apache.org/licenses/LICENSE-2.0

    Unless required by applicable law or agreed to in writing, software
    distributed under the License is distributed on an "AS IS" BASIS,
    WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
    See the License for the specific language governing permissions and
    limitations under the License.

For details, see the version history or ask the package maintainer.
